<?php

/*
|--------------------------------------------------------------------------
| SAML-based Single Sign On related routes
|--------------------------------------------------------------------------
|
| middleware: session
| \Buckhill\LaravelSAML\Http\Controllers\SSO@mapConnectionRoutes
|
*/

$routes = config('sso.SP.routes', []);

foreach($routes as $type => $route)
{
    if(isset($route['methods']))
    {
        foreach($route['methods'] as $method)
        {
            call_user_func_array([Illuminate\Support\Facades\Route::class, $method], [$route['path'], $route['controller']]);
        }
    }
}
